@@ -43,6 +43,6 @@ Blue <- function(std = "ISO") {
                  wb.label = label)
   } else {
     warning("'std' = '", std, "' not implemented.")
-    NA
+    waveband()
   }
 }
