@@ -22,9 +22,18 @@
 #'
 #' @family BSWF weighted wavebands
 #'
-CIE <- function(norm = 298, w.low = 250, w.high = 400) {
-  new_waveband(w.low = w.low, w.high = w.high,
-               weight = "SWF", SWF.e.fun = CIE_e_fun, SWF.norm = 298,
-               norm = norm, hinges=c(250 - 1e-12, 250, 298, 328, 400 - 1e-12, 400),
-               wb.name = paste("CIE98", as.character(norm), sep = "."), wb.label = "CIE98")
+CIE <- function(norm = 298,
+                w.low = 250,
+                w.high = 400) {
+  new_waveband(
+    w.low = w.low,
+    w.high = w.high,
+    weight = "SWF",
+    SWF.e.fun = CIE_e_fun,
+    SWF.norm = 298,
+    norm = norm,
+    hinges = c(250 - 1e-12, 250, 298, 328, 400 - 1e-12, 400),
+    wb.name = paste("CIE98", as.character(norm), sep = "."),
+    wb.label = "CIE98"
+  )
 }
