@@ -24,6 +24,6 @@ Orange <- function(std = "ISO") {
     )
   } else {
     warning("'std' = '", std, "' not implemented.")
-    NA
+    waveband()
   }
 }
