@@ -105,6 +105,6 @@ Red <- function(std = "ISO") {
                  wb.label = label)
   } else {
     warning("'std' = '", std, "' not implemented.")
-    NA
+    waveband()
   }
 }
