@@ -46,6 +46,6 @@ UVC <- function(std = "ISO") {
     )
   } else {
     warning("'std' = '", std, "' not implemented.")
-    NA
+    waveband()
   }
 }
